package fr.unistra.sil.erp.back.controller.api;

import com.fasterxml.jackson.annotation.JsonProperty;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Positive;
import java.math.BigDecimal;

/**
 *
 * @author antoine.beauvais
 */
public class PostItemDTO {
    /**
     * The product's name.
     */
    @NotBlank
    private final String name;

    /**
     * The product's regular price.
     */
    @NotNull
    @Positive
    private final BigDecimal price;

    /**
     * The product's price for subscribers.
     */
    @NotNull
    @Positive
    private final BigDecimal subscriberPrice;

    /**
     * This product's category identifier.
     */
    @NotNull
    @Positive
    private final int category;

    /**
     *
     * @param name
     * @param price
     * @param subscriberPrice
     * @param category
     */
    public PostItemDTO(
            @JsonProperty("name") String name,
            @JsonProperty("price") BigDecimal price,
            @JsonProperty("subscriber_price") BigDecimal subscriberPrice,
            @JsonProperty("category") int category
    ) {
        this.name = name;
        this.price = price;
        this.subscriberPrice = subscriberPrice;
        this.category = category;
    }

    /**
     *
     * @return
     */
    public String getName() {
        return name;
    }

    /**
     *
     * @return
     */
    public BigDecimal getPrice() {
        return price;
    }

    /**
     *
     * @return
     */
    @JsonProperty("subscriber_price")
    public BigDecimal getSubscriberPrice() {
        return subscriberPrice;
    }

    /**
     *
     * @return
     */
    public int getCategory() {
        return category;
    }
}
