/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.model;

import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Representation of a stock entry.
 * 
 * Stocks simply provide the available quantity for each item.
 * 
 * If an item's quantity is depleted, it cannot be sold.
 * 
 * @author BEAUVAIS ANTOINE
 */
public class Stock {
    
    /**
     * The stock entry's ID.
     */
    private final int id;
    
    /**
     * The stock's item ID.
     */
    @JsonProperty("item_id")
    private final int itemId;
    
    /**
     * The stock's item name.
     */
    @JsonProperty("item_name")
    private final String itemName;
    
    /**
     * The quantity for the item.
     */
    private int quantity;
    
    /**
     * Class constructor.
     * @param id the Stock's ID.
     * @param itemId the item's ID.
     * @param itemName the item's name.
     * @param quantity the quantity.
     */
    public Stock(int id, int itemId, String itemName, int quantity)
    {
        this.id = id;
        this.itemId = itemId;
        this.itemName = itemName;
        this.quantity = quantity;
    }
    
    /**
     * Returns the stock ID.
     * @return the stock's ID.
     */
    public int getId()
    {
        return this.id;
    }
    
    /**
     * Returns the item's ID.
     * @return the item's ID.
     */
    public int getItemId()
    {
        return this.itemId;
    }
    
    /**
     * Returns the item's name.
     * @return the item's name.
     */
    public String getItemName()
    {
        return this.itemName;
    }
    
    /**
     * Returns the quantity for the item.
     * @return the quantity.
     */
    public int getQuantity()
    {
        return this.quantity;
    }

    /**
     *
     * @param quantity
     */
    public void addQuantity(int quantity) {
        this.quantity += quantity;
        if (this.quantity < 0) {
            this.quantity = 0;
        }
    }
}
